@@ -40,9 +40,9 @@
 #include <KCModuleInfo>
 #include <KCModuleProxy>
 #include <KStandardGuiItem>
-#include <kauthaction.h>
+#include <KAuthAction>
 #include <KAboutData>
-#include <kauthobjectdecorator.h>
+#include <KAuthObjectDecorator>
 #include <KIconLoader>
 
 #include <KActivities/ResourceInstance>
@@ -64,6 +64,7 @@ public:
     QPushButton* mHelp = nullptr;
     bool pageChangeSupressed = false;
     bool mSaveStatistics = true;
+    bool mDefaultsIndicatorsVisible = false;
 };
 
 ModuleView::ModuleView( QWidget * parent )
@@ -296,6 +297,7 @@ bool ModuleView::moduleSave(KCModuleProxy *module)
     }
 
     module->save();
+    emit moduleSaved();
     return true;
 }
 
@@ -369,6 +371,7 @@ void ModuleView::activeModuleChanged(KPageWidgetItem * current, KPageWidgetItem
                 style()->pixelMetric(QStyle::PM_LayoutRightMargin),
                 style()->pixelMetric(QStyle::PM_LayoutBottomMargin));
         }
+        moduleShowDefaultsIndicators(d->mDefaultsIndicatorsVisible);
     }
 }
 
@@ -476,3 +479,11 @@ bool ModuleView::isResetVisible() const
     return d->mReset->isVisible();
 }
 
+void ModuleView::moduleShowDefaultsIndicators(bool show)
+{
+    d->mDefaultsIndicatorsVisible = show;
+    KCModuleProxy * activeModule = d->mPages.value(d->mPageWidget->currentPage());
+    if (activeModule) {
+        activeModule->setDefaultsIndicatorsVisible(show);
+    }
+}
