@@ -95,6 +95,53 @@ public:
 
     KPageView::FaceType faceType() const;
 
+    /**
+     * Sets whether Systemsettings should save statisctics about
+     * most used modules using KActivities::Stats
+     */
+    void setSaveStatistics(bool save);
+
+    /**
+     * @returns whether Systemsettings should save statisctics about
+     * most used module
+     */
+    bool saveStatistics() const;
+
+    /**
+     * Shows or hides the Apply button.
+     */
+    void setApplyVisible(bool visible);
+
+    /**
+     * @returns True if the Apply button is visible.
+     */
+    bool isApplyVisible() const;
+
+    /**
+     * Shows or hides the Defaults button.
+     */
+    void setDefaultsVisible(bool visible);
+
+    /**
+     * @returns True if the Defaults button is visible.
+     */
+    bool isDefaultsVisible() const;
+
+    /**
+     * Shows or hides the Reset button.
+     */
+    void setResetVisible(bool visible);
+
+    /**
+     * @returns True if the Reset button is visible.
+     */
+    bool isResetVisible() const;
+
+    /**
+     * Show or hide defaults indicators (field level)
+     */
+    void moduleShowDefaultsIndicators(bool show);
+
 public Q_SLOTS:
     /**
      * Loads the module specified by menuItem.\n
@@ -102,7 +149,7 @@ public Q_SLOTS:
      *
      * @param menuItem the QModelIndex that you want to load. Must be sourced from either MenuModel or MenuProxyModel
      */
-    void loadModule(const QModelIndex &menuItem );
+    void loadModule(const QModelIndex &menuItem, const QStringList &args );
 
     /**
      * Will open KHelpCenter, and load the help for the active module.
@@ -131,7 +178,7 @@ public Q_SLOTS:
 
 private:
     bool resolveChanges( KCModuleProxy *currentProxy );
-    void addModule( KCModuleInfo *module );
+    void addModule( KCModuleInfo *module, const QStringList &args );
     bool moduleSave( KCModuleProxy *module );
     void updatePageIconHeader( KPageWidgetItem * page, bool light = false );
 
@@ -146,11 +193,21 @@ Q_SIGNALS:
      */
     void moduleChanged( bool state );
 
+    /**
+     * Emitted after the currently active module was saved.
+     */
+    void moduleSaved();
+
     /**
      * Emitted when the ModuleView is asked to close.\n
      */
     void closeRequest();
 
+    /**
+     * Emmitted when showDefaultsIndicators state changed
+     */
+     void showDefaultsIndicatorsChanged(bool show);
+
 private:
     class Private;
     Private *const d;
