@@ -79,9 +79,13 @@ void FocusHackWidget::focusPrevious()
 }
 
 SubcategoryModel::SubcategoryModel(QAbstractItemModel *parentModel, QObject *parent)
-    : QStandardItemModel(parent),
+    : KSelectionProxyModel(nullptr, parent),
         m_parentModel(parentModel)
-{}
+{
+    setSourceModel(parentModel);
+    setSelectionModel(new QItemSelectionModel(parentModel, this));
+    setFilterBehavior(SubTreesWithoutRoots);
+}
 
 QString SubcategoryModel::title() const
 {
@@ -90,23 +94,7 @@ QString SubcategoryModel::title() const
 
 void SubcategoryModel::setParentIndex(const QModelIndex &activeModule)
 {
-    blockSignals(true);
-    //make the view receive a single signal when the new subcategory is loaded,
-    //never make the view believe there are zero items if this is not the final count
-    //this avoids the brief flash it had
-    clear();
-    const int subRows = activeModule.isValid() ? m_parentModel->rowCount(activeModule) : 0;
-    if ( subRows > 1) {
-        for (int i = 0; i < subRows; ++i) {
-            const QModelIndex& index = m_parentModel->index(i, 0, activeModule);
-            QStandardItem *item = new QStandardItem(m_parentModel->data(index, Qt::DecorationRole).value<QIcon>(), m_parentModel->data(index, Qt::DisplayRole).toString());
-            item->setData(index.data(Qt::UserRole), Qt::UserRole);
-            appendRow(item);
-        }
-    }
-    blockSignals(false);
-    beginResetModel();
-    endResetModel();
+    selectionModel()->select(activeModule, QItemSelectionModel::ClearAndSelect);
     m_title = activeModule.data(Qt::DisplayRole).toString();
     emit titleChanged();
 }
@@ -274,6 +262,7 @@ public:
         emit sidebarMode->actionMenuVisibleChanged();
     }
     bool m_introPageVisible = true;
+    bool m_defaultsIndicatorsVisible = false;
 };
 
 SidebarMode::SidebarMode( QObject *parent, const QVariantList &args )
@@ -372,6 +361,7 @@ void SidebarMode::initEvent()
     d->mainLayout->setContentsMargins(0, 0, 0, 0);
     d->moduleView = new ModuleView( d->mainWidget );
     connect( d->moduleView, &ModuleView::moduleChanged, this, &SidebarMode::moduleLoaded );
+    connect(d->moduleView, &ModuleView::moduleSaved, this, &SidebarMode::updateDefaults);
     d->quickWidget = nullptr;
     moduleView()->setFaceType(KPageView::Plain);
     if (applicationMode() == BaseMode::InfoCenter) {
@@ -569,6 +559,30 @@ void SidebarMode::moduleLoaded()
 {
     d->placeHolderWidget->hide();
     d->moduleView->show();
+    if (applicationMode() == BaseMode::InfoCenter) {
+        d->moduleView->setSaveStatistics(false);
+        d->moduleView->setApplyVisible(false);
+        d->moduleView->setDefaultsVisible(false);
+        d->moduleView->setResetVisible(false);
+    }
+}
+
+void SidebarMode::updateDefaults()
+{
+    QModelIndex categoryIdx = d->categorizedModel->index(d->activeCategoryRow, 0);
+    auto item = categoryIdx.data(Qt::UserRole).value<MenuItem*>();
+    Q_ASSERT(item);
+    // If subcategory exist update from subcategory
+    if (!item->children().isEmpty()) {
+        item = item->child(d->activeSubCategoryRow);
+    }
+    item->updateDefaultIndicator();
+
+    auto sourceIdx = d->categorizedModel->mapToSource(categoryIdx);
+    emit d->model->dataChanged(sourceIdx, sourceIdx);
+
+    auto subCateogryIdx = d->subCategoryModel->index(d->activeSubCategoryRow, 0);
+    emit d->subCategoryModel->dataChanged(subCateogryIdx, subCateogryIdx);
 }
 
 int SidebarMode::activeSearchRow() const
@@ -596,6 +610,7 @@ void SidebarMode::setIntroPageVisible(const bool &introPageVisible)
         }
     } else {
         if (introPageVisible) {
+            d->subCategoryModel->setParentIndex(QModelIndex());
             d->activeCategoryRow = -1;
             emit activeCategoryRowChanged();
             d->activeSubCategoryRow = -1;
@@ -612,6 +627,41 @@ void SidebarMode::setIntroPageVisible(const bool &introPageVisible)
     emit introPageVisibleChanged();
 }
 
+void SidebarMode::toggleDefaultsIndicatorsVisibility()
+{
+    d->m_defaultsIndicatorsVisible = !d->m_defaultsIndicatorsVisible;
+    d->moduleView->moduleShowDefaultsIndicators(d->m_defaultsIndicatorsVisible);
+
+    if (d->m_defaultsIndicatorsVisible) {
+        for (int i = 0; i < d->flatModel->rowCount(); ++i) {
+            QModelIndex idx = d->flatModel->index(i, 0);
+            auto item = idx.data(MenuModel::MenuItemRole).value<MenuItem *>();
+            if (item->menu()) {
+                continue;
+            }
+            const bool showIndicator = item->showDefaultIndicator();
+            item->updateDefaultIndicator();
+            if (showIndicator == item->showDefaultIndicator()) {
+                continue;
+            }
+            auto itemIdx = d->model->indexForItem(item);
+            emit d->model->dataChanged(itemIdx, itemIdx);
+            MenuItem *parent = item->parent();
+            while (parent) {
+                auto parentIdx = d->model->indexForItem(parent);
+                if (parentIdx.isValid()) {
+                    emit d->model->dataChanged(parentIdx, parentIdx);
+                    parent = parent->parent();
+                } else {
+                    parent = nullptr;
+                }
+            }
+        }
+    }
+
+    emit defaultsIndicatorsVisibleChanged();
+}
+
 int SidebarMode::width() const
 {
     return d->mainWidget->width();
@@ -632,6 +682,11 @@ bool SidebarMode::introPageVisible() const
     return (d->m_introPageVisible);
 }
 
+bool SidebarMode::defaultsIndicatorsVisible() const
+{
+    return d->m_defaultsIndicatorsVisible;
+}
+
 void SidebarMode::initWidget()
 {
     // Create the widgets
@@ -646,6 +701,7 @@ void SidebarMode::initWidget()
     d->quickWidget = new QQuickWidget(d->mainWidget);
     d->quickWidget->quickWindow()->setTitle(i18n("Sidebar"));
     d->quickWidget->setResizeMode(QQuickWidget::SizeRootObjectToView);
+    qmlRegisterUncreatableType<SidebarMode>("org.kde.systemsettings", 1, 0, "SystemSettings", QStringLiteral("Not creatable, use the systemsettings attached property"));
 
     d->quickWidget->engine()->rootContext()->setContextProperty(QStringLiteral("systemsettings"), this);
     d->package = KPackage::PackageLoader::self()->loadPackage(QStringLiteral("KPackage/GenericQML"));
